#include <XSUtil/Utils/XSutility.h>

void clcmek(int itype, const float* ear, int ne, const float* tparam, int ifl, float* photmp);

void smdem0(int itype, const float* ear, int ne, const float* abun, float dens, float z,
                int ninputt, const float* inputt, const float* dem, int ifl, float* photar,
                int* status)
{
   //  Subroutine to calculate the summed emission from plasma with a
   //  DEM given by the input array. This routine handles the case of
   //  the model being calculated
   //  Arguments :
   //       itype   I        i: type of plasma emission file
   //                             2 = Mekal
   //                             3 = Meka
   //       ear     R        i: model energy ranges
   //       ne      I        i: number of model energies
   //       abun    R        i: abundances
   //       dens    R        i: density (cm^-3)
   //       z       R        i: redshift
   //       ninputt I        i: number of temperatures
   //       inputt  R        i: temperatures
   //       dem     R        i: emission measures for input temperatures
   //       ifl     I        i: dataset number (unused at present)
   //       photar  R        r: spectrum
   //       status  I        r: 0==OK
   
   //   Translated from smdem0.f Feb 09
   
   *status = 0;
   
   // temporary array
   XSutility::auto_array_ptr<float> apPhotmp(new float[ne]);
   float* photmp = apPhotmp.get();
   
   // Set the parameters for the calculation
   
   float tparam[17];
   tparam[1] = dens;
   for (int i=2; i<16; ++i)
      tparam[i] = abun[i-2];
   tparam[16] = z;
   
   // Initialize the output array
   
   for (int i=0; i<ne; ++i)
      photar[i] = 0.0;
      
   // Loop over temperatures
   
   for (int i=0; i<ninputt; ++i)
      if (dem[i] != 0.0)
      {
         tparam[0] = inputt[i];
         clcmek(itype, ear, ne, tparam, ifl, photmp);
         
         // Add the current contribution into the total model
         
         for (int j=0; j<ne; ++j)
            photar[j] += dem[i]*photmp[j];
      }
   
}
